/*
 * $Id$
 */

/**
 * Configure the RTEMS initialisation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdlib.h>

#include <rtems.h>

#if !RTEMS_APP_NETWORKING
#undef RTEMS_NETWORKING
#endif

#ifdef RTEMS_NETWORKING
#include <rtems/rtems_bsdnet.h>
#include <rtems/dhcp.h>
#endif

/*
 * Declare main.
 */
int main (int argc, char** argv, char** envp);

rtems_task
Init (rtems_task_argument ignored)
{
  /*
   * In bootcard.c in the sharded BSP support.
   */
  extern char* rtems_progname;
  
  char* argv[1];
  argv[0] = rtems_progname;

#ifdef RTEMS_NETWORKING
  rtems_bsdnet_initialize_network ();
#endif

  exit (main (1, argv, NULL));
}

/**
 * Configure base RTEMS resources.
 */
#define CONFIGURE_RTEMS_INIT_TASKS_TABLE
#define CONFIGURE_MEMORY_OVERHEAD                  512
#define CONFIGURE_MAXIMUM_TASKS                    rtems_resource_unlimited (10)
#define CONFIGURE_MAXIMUM_SEMAPHORES               rtems_resource_unlimited (10)
#define CONFIGURE_MAXIMUM_MESSAGE_QUEUES           rtems_resource_unlimited (5)
#define CONFIGURE_MAXIMUM_PARTITIONS               rtems_resource_unlimited (2)

/**
 * Configure drivers.
 */
#define CONFIGURE_MAXIMUM_DRIVERS                  10
#define CONFIGURE_APPLICATION_NEEDS_CONSOLE_DRIVER
#define CONFIGURE_APPLICATION_NEEDS_CLOCK_DRIVER

/**
 * Configure file system and libblock.
 */
#define CONFIGURE_USE_IMFS_AS_BASE_FILESYSTEM
#define CONFIGURE_LIBIO_MAXIMUM_FILE_DESCRIPTORS   20
#define CONFIGURE_APPLICATION_NEEDS_LIBBLOCK
#define CONFIGURE_SWAPOUT_TASK_PRIORITY            10

#if RTEMS_APP_IDEDISK
#define CONFIGURE_BDBUF_BUFFER_COUNT               1024
#define CONFIGURE_BDBUF_MAX_READ_AHEAD_BLOCKS      64
#define CONFIGURE_BDBUF_MAX_WRITE_BLOCKS           32
#define CONFIGURE_APPLICATION_NEEDS_IDE_DRIVER
#define CONFIGURE_APPLICATION_NEEDS_ATA_DRIVER
#define CONFIGURE_ATA_DRIVER_TASK_PRIORITY         9
#endif

/**
 * Tell confdefs.h to provide the configuration.
 */
#define CONFIGURE_INIT

#include <rtems/confdefs.h>

#ifdef RTEMS_NETWORKING
#if pc586
int rtems_fxp_attach(struct rtems_bsdnet_ifconfig *config, int attaching);
#define CONFIGURE_NETWORK_DRIVER_NAME   "fxp1"
#define CONFIGURE_NETWORK_DRIVER_ATTACH rtems_fxp_attach
#define CONFIGURE_ETHERNET_ADDRESS      0x00, 0x08, 0xc7, 0x21, 0x01, 0xf9
#else
#define CONFIGURE_NETWORK_DRIVER_NAME   "fec0"
#define CONFIGURE_NETWORK_DRIVER_ATTACH rtems_fec_driver_attach
#define CONFIGURE_ETHERNET_ADDRESS      0x00, 0x20, 0xDD, 0xFF, 0x00, 0x01
#endif
#define CONFIGURE_NETWORK_DHCP

#include "networkconfig.h"
#endif

#define CONFIGURE_SHELL_COMMANDS_INIT
#define CONFIGURE_SHELL_COMMANDS_ALL
#define CONFIGURE_SHELL_MOUNT_MSDOS
#ifdef RTEMS_NETWORKING
#define CONFIGURE_SHELL_MOUNT_TFTP
#define CONFIGURE_SHELL_MOUNT_FTP
#define CONFIGURE_SHELL_MOUNT_NFS
#endif

#include <rtems/shellconfig.h>
